@@ -36,6 +36,7 @@ from sqlalchemy import NVARCHAR
 from sqlalchemy import PrimaryKeyConstraint
 from sqlalchemy import schema
 from sqlalchemy import select
+from sqlalchemy import Sequence
 from sqlalchemy import SmallInteger
 from sqlalchemy import sql
 from sqlalchemy import String
@@ -61,6 +62,7 @@ from sqlalchemy.sql import column
 from sqlalchemy.sql import delete
 from sqlalchemy.sql import table
 from sqlalchemy.sql import update
+from sqlalchemy.sql.ddl import CreateSequence
 from sqlalchemy.sql.expression import bindparam
 from sqlalchemy.sql.expression import literal_column
 from sqlalchemy.testing import assert_raises_message
@@ -453,6 +455,26 @@ class CompileTest(ReservedWordFixture, fixtures.TestBase, AssertsCompiledSQL):
                 DateTime,
                 server_default=text("now() ON UPDATE now()"),
             ),
+            Column(
+                "updated4",
+                DateTime,
+                server_default=text("now(3)"),
+            ),
+            Column(
+                "updated5",
+                DateTime,
+                server_default=text("nOW(3)"),
+            ),
+            Column(
+                "updated6",
+                DateTime,
+                server_default=text("notnow(1)"),
+            ),
+            Column(
+                "updated7",
+                DateTime,
+                server_default=text("CURRENT_TIMESTAMP(3)"),
+            ),
         )
 
         eq_(dialect._support_default_function, has_brackets)
@@ -467,7 +489,11 @@ class CompileTest(ReservedWordFixture, fixtures.TestBase, AssertsCompiledSQL):
                 "data JSON DEFAULT (json_object()), "
                 "updated1 DATETIME DEFAULT now() on update now(), "
                 "updated2 DATETIME DEFAULT now() On  UpDate now(), "
-                "updated3 DATETIME DEFAULT now() ON UPDATE now())",
+                "updated3 DATETIME DEFAULT now() ON UPDATE now(), "
+                "updated4 DATETIME DEFAULT now(3), "
+                "updated5 DATETIME DEFAULT nOW(3), "
+                "updated6 DATETIME DEFAULT (notnow(1)), "
+                "updated7 DATETIME DEFAULT CURRENT_TIMESTAMP(3))",
                 dialect=dialect,
             )
         else:
@@ -480,7 +506,11 @@ class CompileTest(ReservedWordFixture, fixtures.TestBase, AssertsCompiledSQL):
                 "data JSON DEFAULT json_object(), "
                 "updated1 DATETIME DEFAULT now() on update now(), "
                 "updated2 DATETIME DEFAULT now() On  UpDate now(), "
-                "updated3 DATETIME DEFAULT now() ON UPDATE now())",
+                "updated3 DATETIME DEFAULT now() ON UPDATE now(), "
+                "updated4 DATETIME DEFAULT now(3), "
+                "updated5 DATETIME DEFAULT nOW(3), "
+                "updated6 DATETIME DEFAULT notnow(1), "
+                "updated7 DATETIME DEFAULT CURRENT_TIMESTAMP(3))",
                 dialect=dialect,
             )
 
@@ -1050,6 +1080,36 @@ class SQLTest(fixtures.TestBase, AssertsCompiledSQL):
             ")ENGINE=InnoDB",
         )
 
+    @testing.combinations(
+        (Sequence("foo_seq"), "CREATE SEQUENCE foo_seq"),
+        (Sequence("foo_seq", cycle=True), "CREATE SEQUENCE foo_seq CYCLE"),
+        (Sequence("foo_seq", cycle=False), "CREATE SEQUENCE foo_seq NOCYCLE"),
+        (
+            Sequence(
+                "foo_seq",
+                start=1,
+                increment=2,
+                nominvalue=True,
+                nomaxvalue=True,
+                cycle=False,
+                cache=100,
+            ),
+            (
+                "CREATE SEQUENCE foo_seq INCREMENT BY 2 START WITH 1 NO"
+                " MINVALUE NO MAXVALUE CACHE 100 NOCYCLE"
+            ),
+        ),
+        argnames="seq, expected",
+    )
+    @testing.variation("use_mariadb", [True, False])
+    def test_mariadb_sequence_behaviors(self, seq, expected, use_mariadb):
+        """test #13073"""
+        self.assert_compile(
+            CreateSequence(seq),
+            expected,
+            dialect="mariadb" if use_mariadb else "mysql",
+        )
+
     def test_create_table_with_partition(self):
         t1 = Table(
             "testtable",
